@@ -308,6 +308,22 @@ def get_all_score_strings(machine):
     envvar="GORDO_SERVER_WORKER_CONNECTIONS",
     show_default=True,
 )
+@click.option(
+    "--threads",
+    type=int,
+    help="The number of worker threads for handling requests."
+    "This argument only has affects with --worker-class=gthread. "
+    "Default value is 8 (4 x $(NUM_CORES))",
+    default=8,
+    envvar="GORDO_SERVER_THREADS",
+)
+@click.option(
+    "--worker-class",
+    help="The type of workers to use.",
+    default="gthread",
+    envvar="GORDO_SERVER_WORKER_CLASS",
+    show_default=True,
+)
 @click.option(
     "--log-level",
     type=click.Choice(Logger.LOG_LEVELS.keys()),
@@ -316,11 +332,46 @@ def get_all_score_strings(machine):
     envvar="GORDO_SERVER_LOG_LEVEL",
     show_default=True,
 )
-def run_server_cli(host, port, workers, worker_connections, log_level):
+@click.option(
+    "--server-app",
+    help="The application to run",
+    default="gordo.server.server:build_app()",
+    envvar="GORDO_SERVER_APP",
+    show_default=True,
+)
+@click.option(
+    "--with-prometheus-config",
+    help="Run with custom config for prometheus",
+    is_flag=True,
+)
+def run_server_cli(
+    host,
+    port,
+    workers,
+    worker_connections,
+    threads,
+    worker_class,
+    log_level,
+    server_app,
+    with_prometheus_config,
+):
     """
     Run the gordo server app with Gunicorn
     """
-    server.run_server(host, port, workers, worker_connections, log_level.lower())
+    config_module = None
+    if with_prometheus_config:
+        config_module = "gordo.server.prometheus.gunicorn_config"
+    server.run_server(
+        host,
+        port,
+        workers,
+        log_level.lower(),
+        config_module=config_module,
+        worker_connections=worker_connections,
+        threads=threads,
+        worker_class=worker_class,
+        server_app=server_app,
+    )
 
 
 gordo.add_command(workflow_cli)
