@@ -220,6 +220,24 @@ def test_join_timeseries_with_interpolation_method_linear_interpolation(dataset)
     assert len(all_in_frame) == 337
 
 
+def test_join_timeseries_with_interpolation_method_linear_interpolation_no_limit(
+    dataset,
+):
+    timeseries_list, latest_start, earliest_end = create_timeseries_list()
+    resampling_start = dateutil.parser.isoparse("2017-01-01 06:00:00+07:00")
+    resampling_end = dateutil.parser.isoparse("2018-02-01 13:07:00+07:00")
+
+    all_in_frame = dataset.join_timeseries(
+        timeseries_list,
+        resampling_start,
+        resampling_end,
+        resolution="10T",
+        interpolation_method="linear_interpolation",
+        interpolation_limit=None,
+    )
+    assert len(all_in_frame) == 4177
+
+
 def test_row_filter():
     """Tests that row_filter filters away rows"""
     kwargs = dict(
