@@ -137,6 +137,8 @@ def test_machine_from_config(default_globals: dict):
             },
             "default_asset": None,
             "high_threshold": 50000,
+            "interpolation_limit": "8H",
+            "interpolation_method": "linear_interpolation",
             "low_threshold": -1000,
             "n_samples_threshold": 0,
             "resolution": "10T",
